.. image:: https://travis-ci.org/lcorbasson/agate-mdb.png
    :target: https://travis-ci.org/lcorbasson/agate-mdb
    :alt: Build status

.. image:: https://img.shields.io/pypi/v/agate-mdb.svg
    :target: https://pypi.python.org/pypi/agate-mdb
    :alt: Version

.. image:: https://img.shields.io/pypi/l/agate-mdb.svg
    :target: https://pypi.python.org/pypi/agate-mdb
    :alt: License

.. image:: https://img.shields.io/pypi/pyversions/agate-mdb.svg
    :target: https://pypi.python.org/pypi/agate-mdb
    :alt: Support Python versions

agate-mdb adds read support for Microsoft Access files (\*.mdb, \*.accdb) to `agate <https://github.com/wireservice/agate>`_, with the help of `mdbtools <https://github.com/mdbtools/mdbtools>`_.

**It's still a work in progress. Caveat emptor!**

Important links:

* agate             http://agate.rtfd.org
* Documentation:    http://agate-mdb.rtfd.org
* Repository:       https://github.com/lcorbasson/agate-mdb
* Issues:           https://github.com/lcorbasson/agate-mdb/issues
